View source: R/att_definition.R
| get_attribute_definition_function | R Documentation |
Each attribute is defined by a function that adds a column to a table based on the parameter that contains the date or time. This function returns the definition function for the attribute whose name is given.
get_attribute_definition_function(td, name)
## S3 method for class 'when'
get_attribute_definition_function(td, name = NULL)
td |
A |
name |
A string, attribute name. |
A function.
Other dimension definition:
define_characteristics(),
define_instances(),
get_day_part(),
get_week_date_range(),
select_date_levels(),
select_day_level(),
select_month_level(),
select_quarter_level(),
select_semester_level(),
select_time_level(),
select_week_level(),
select_year_level(),
set_attribute_definition_function(),
set_day_part(),
when()
f <- when() |>
get_attribute_definition_function(name = "year")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.