get_table_xlsx: Store the table in a xlsx file

View source: R/export.R

get_table_xlsxR Documentation

Store the table in a xlsx file

Description

Once all the configuration elements have been defined and the dimension table has been generated, using this function we can obtain it in xlsx format.

Usage

get_table_xlsx(td, dir)

## S3 method for class 'when'
get_table_xlsx(td, dir = NULL)

Arguments

td

A when object.

dir

A string, name of a dir.

Details

If no dir name is given, stores the table in a temporary one.

Value

A string, name of a file.

See Also

Other getting results: get_table_csv(), get_table_rdb(), get_table()

Examples


file <- when() |>
  generate_table() |>
  get_table_xlsx()


when documentation built on May 29, 2024, 5:01 a.m.