| get_week_date_range | R Documentation |
For weeks between the given dates, gets the date of the first and last day of each week.
get_week_date_range(start = NULL, end = NULL, type = NULL)
start |
A string, start of the period to be included in the dimension. |
end |
A string, end of the period to be included in the dimension. |
type |
A string, type of calendar (NULL, 'iso', 'epi' or 'time'). |
A tibble.
Other dimension definition:
define_characteristics(),
define_instances(),
get_attribute_definition_function(),
get_day_part(),
select_date_levels(),
select_day_level(),
select_month_level(),
select_quarter_level(),
select_semester_level(),
select_time_level(),
select_week_level(),
select_year_level(),
set_attribute_definition_function(),
set_day_part(),
when()
t <- get_week_date_range(start = "2024-01-01", end = "2029-12-31")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.