| select_time_level | R Documentation |
When the dimension is defined as a time type, using this function we can select the level and its attributes to include in it: time, minute, second and day_part.
select_time_level(td, include_all, exclude_all, time, minute, second, day_part)
## S3 method for class 'when'
select_time_level(
td,
include_all = FALSE,
exclude_all = FALSE,
time = NULL,
minute = NULL,
second = NULL,
day_part = NULL
)
td |
A |
include_all |
A boolean, include all fields of the level. |
exclude_all |
A boolean, exclude all fields of the level. |
time |
A boolean, include a field for the time. |
minute |
A boolean, include the minute level of detail. |
second |
A boolean, include the second level of detail. |
day_part |
A boolean, include the parts of the day. |
The 'hour' attribute will always be included. If the 'minute' attribute is not included the 'second' attribute will not be included either.
A when object.
Other dimension definition:
define_characteristics(),
define_instances(),
get_attribute_definition_function(),
get_day_part(),
get_week_date_range(),
select_date_levels(),
select_day_level(),
select_month_level(),
select_quarter_level(),
select_semester_level(),
select_week_level(),
select_year_level(),
set_attribute_definition_function(),
set_day_part(),
when()
td <- when() |>
select_time_level(day_part = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.