| get_table_xlsx | R Documentation |
Once all the configuration elements have been defined and the dimension table has been generated, using this function we can obtain it in xlsx format.
get_table_xlsx(td, dir)
## S3 method for class 'when'
get_table_xlsx(td, dir = NULL)
td |
A |
dir |
A string, name of a dir. |
If no dir name is given, stores the table in a temporary one.
A string, name of a file.
Other getting results:
get_table_csv(),
get_table_rdb(),
get_table()
file <- when() |>
generate_table() |>
get_table_xlsx()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.